@@ -4,19 +4,20 @@
  *           Brian Goetz <brian@quiotix.com>
  *           Loic Dachary <loic@dachary.org>
  *
- *  This package is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 dated June, 1991.
+ * This program gives you software freedom; you can copy, convey,
+ * propagate, redistribute and/or modify this program under the terms of
+ * the GNU General Public License (GPL) as published by the Free Software
+ * Foundation (FSF), either version 3 of the License, or (at your option)
+ * any later version of the GPL published by the FSF.
  *
- *  This package is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this package; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program in a file in the toplevel directory called "GPLv3".
+ * If not, see <http://www.gnu.org/licenses/>.
  */
 /*
 Macros to enumerate combinations and permutations of the remaining
@@ -641,7 +642,7 @@ do { \
         if (!deck##_CardMask_ANY_SET(_unavail, set_var[_i])) \
           break;	/* this hand is available for player i */ \
       } \
-      if (_j == _ncombo[_i]) { printf("not enough cards\n"); exit(1); } \
+      if (_j == _ncombo[_i]) { printf("not enough cards\n"); return(1); } \
       deck##_CardMask_OR(_unavail, _unavail, set_var[_i]); \
       _curIndex[_i] = _j; \
     } \
